## ----include = FALSE-----------------------------------------------------
library(optional)

## ------------------------------------------------------------------------
a <- some(5)
class(a)

## ------------------------------------------------------------------------
a == 5
a

## ------------------------------------------------------------------------
c_opt <- make_opt(c)
c_opt(some(2), none, some(5))
c_opt()

## ------------------------------------------------------------------------
library(magrittr)

a <- 5
match_with(a,
  . %>% some(.),          paste,
  none,                   function() "Error!"
)

## ------------------------------------------------------------------------
a <- 4
match_with(a,
  1,                 function() "Matched exact value",
  list(2, 3, 4),     fallthrough(function() "Matched in list"),
  . %>% if (. > 3)., function(x) paste0("Matched in condition: ",x,">3")
)

